@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 
@@ -117,6 +118,7 @@ class CodePipelineClient:
     [CodePipeline.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codepipeline.html#CodePipeline.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def acknowledge_job(self, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
